@@ -119,6 +119,11 @@ def write_default_ansible_cfg(work_dir,
                     datetime.now().strftime("%Y-%m-%dT%H:%M:%S"))
         os.rename(log_path, new_path)
 
+    # Create the log file, and set some rights on it in order to prevent
+    # unwanted access
+    open(log_path, 'a').close()
+    os.chmod(log_path, 0o640)
+
     config.set('defaults', 'forks', str(min(
         multiprocessing.cpu_count() * 4, 100)))
     config.set('defaults', 'timeout', '30')
