@@ -30,7 +30,6 @@ from tripleo_common import exception
 from tripleo_common.utils import plan as plan_utils
 from tripleo_common.utils import roles as roles_utils
 from tripleo_common.utils import swift as swiftutils
-from tripleo_common.utils import tarball
 from tripleo_common.utils.validations import pattern_validator
 
 
@@ -215,135 +214,6 @@ class ExportPlanAction(base.TripleOAction):
             shutil.rmtree(tmp_dir)
 
 
-class UpdatePlanFromDirAction(base.TripleOAction):
-    """Updates a plan and associated files
-
-    Updates a plan by comparing the current files with the new ones
-    provided:
-        Updates only new files from the plan
-        Add new files from the plan
-
-    :param container: name of the Swift container / plan name
-    """
-
-    def __init__(self, container=constants.DEFAULT_CONTAINER_NAME,
-                 templates_dir=constants.DEFAULT_TEMPLATES_PATH):
-        super(UpdatePlanFromDirAction, self).__init__()
-        self.container = container
-        self.templates_dir = templates_dir
-
-    def run(self, context):
-        try:
-            swift = self.get_object_client(context)
-            # Upload template dir to tmp container
-            container_tmp = '%s-tmp' % self.container
-            with tempfile.NamedTemporaryFile() as tmp_tarball:
-                tarball.create_tarball(self.templates_dir, tmp_tarball.name)
-                tarball.tarball_extract_to_swift_container(
-                    swift,
-                    tmp_tarball.name,
-                    container_tmp)
-            # Get all new templates:
-            new_templates = swiftutils.get_object_string(swift, container_tmp,
-                                                         '').splitlines()
-            old_templates = swiftutils.get_object_string(swift, self.container,
-                                                         '').splitlines()
-            exclude_user_data = [constants.PLAN_ENVIRONMENT,
-                                 constants.OVERCLOUD_J2_ROLES_NAME,
-                                 constants.OVERCLOUD_J2_NETWORKS_NAME,
-                                 constants.OVERCLOUD_J2_EXCLUDES]
-            # Update the old container
-            for new in new_templates:
-                # if doesn't exist, push it:
-                if new not in old_templates:
-                    swiftutils.put_object_string(
-                        swift,
-                        self.container,
-                        new,
-                        swiftutils.get_object_string(swift, container_tmp, new)
-                    )
-                else:
-                    content_new = swiftutils.get_object_string(swift,
-                                                               container_tmp,
-                                                               new)
-                    content_old = swiftutils.get_object_string(swift,
-                                                               self.container,
-                                                               new)
-                    if (not content_new == content_old and
-                       new not in exclude_user_data):
-                        swiftutils.put_object_string(
-                            swift,
-                            self.container,
-                            new,
-                            swiftutils.get_object_string(swift, container_tmp,
-                                                         new)
-                        )
-        except swiftexceptions.ClientException as err:
-            msg = "Error attempting an operation on container: %s" % err
-            LOG.exception(msg)
-            return actions.Result(error=msg)
-        except Exception as err:
-            msg = "Error while updating plan: %s" % err
-            LOG.exception(msg)
-            return actions.Result(error=msg)
-
-
-class UpdatePlanEnvironmentAction(base.TripleOAction):
-    """Updates the plan environment values
-
-    Updates a plan environment values - when parameter is specified
-    the value is merged with the env_key (useful for parameter_defaults)
-    otherwise the value for env_key is replaced.
-
-    :param env_key: environment key that should be one of the keys present
-                    in the plan environment dictionary
-    :param parameter: key value of the parameter add/delete/modify
-    :param value: value of the parameter or of env_key when no parameter
-    :param delete: True if the parameter should be deleted from env_key
-    :param container: name of the Swift container / plan name
-    """
-
-    def __init__(self, env_key, parameter=None, value=None, delete=False,
-                 container=constants.DEFAULT_CONTAINER_NAME):
-        super(UpdatePlanEnvironmentAction, self).__init__()
-        self.container = container
-        self.parameter = parameter
-        self.value = value
-        self.delete = delete
-        self.env_key = env_key
-
-    def run(self, context):
-        try:
-            swift = self.get_object_client(context)
-            plan_env = plan_utils.get_env(swift, self.container)
-
-            if self.env_key not in plan_env:
-                msg = "The environment key doesn't exist: %s" % self.env_key
-                return actions.Result(error=msg)
-
-            if self.delete:
-                if not self.parameter:
-                    raise ValueError("delete must specify a parameter")
-                plan_env[self.env_key].pop(self.parameter, None)
-            elif self.parameter:
-                plan_env[self.env_key][self.parameter] = self.value
-            elif self.value is not None:
-                plan_env[self.env_key] = self.value
-            else:
-                # Nothing to modify
-                return
-
-            plan_utils.update_in_env(swift, plan_env,
-                                     self.env_key,
-                                     value=plan_env[self.env_key])
-        except swiftexceptions.ClientException as err:
-            msg = "Error attempting an operation on container: %s" % err
-            return actions.Result(error=msg)
-        except Exception as err:
-            msg = "Error while updating plan: %s" % err
-            return actions.Result(error=msg)
-
-
 class UpdateNetworksAction(base.TripleOAction):
     def __init__(self, networks, current_networks, replace_all=False):
         super(UpdateNetworksAction, self).__init__()
@@ -451,35 +321,6 @@ class UpdateRolesAction(base.TripleOAction):
         return actions.Result(data={'roles': save_roles})
 
 
-class GatherRolesAction(actions.Action):
-    """Gather role definitions
-
-    Check each role name from the input, check if it exists in
-    roles_data.yaml, if yes, use that role definition, if not, get the
-    role definition from roles directory. Return the gathered role
-    definitions.
-    """
-
-    def __init__(self, role_names, current_roles, available_roles):
-        super(GatherRolesAction, self).__init__()
-        self.role_names = role_names
-        self.current_roles = current_roles
-        self.available_roles = available_roles
-
-    def run(self, context):
-        err_msgs = []
-        # merge the two lists of dicts in the proper order.  last in wins, so
-        # a current role shall be favored over an available role.
-        gathered_roles = [role for role in {
-            x['name']: x for x in self.available_roles + self.current_roles
-        }.values() if role['name'] in self.role_names]
-
-        if err_msgs:
-            return actions.Result(error="/n".join(err_msgs))
-
-        return actions.Result(data={'gathered_roles': gathered_roles})
-
-
 class RemoveNoopDeployStepAction(base.TripleOAction):
     """Remove all the pre, post and deploy step in the plan-environment.
 
