@@ -50,7 +50,7 @@ class TestConfig(base.TestCase):
                             'service_metadata_settings',
                             'service_names',
                             'upgrade_batch_tasks', 'upgrade_tasks',
-                            'external_deploy_tasks']
+                            'external_deploy_steps_tasks']
 
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
@@ -65,6 +65,11 @@ class TestConfig(base.TestCase):
         mock_mkdir.assert_called()
         expected_calls = []
         for config in config_type_list:
+            if 'external' in config:
+                for step in range(constants.DEFAULT_STEPS_MAX):
+                    expected_calls += [call('/tmp/tht/%s_step%s.yaml' %
+                                       (config, step))]
+
             for role in fake_role:
                 if 'external' in config:
                     continue
@@ -171,7 +176,7 @@ class TestConfig(base.TestCase):
                                         % step)
                 playbook_tasks = self.config._write_tasks_per_step(
                     self.config.stack_outputs.get('RoleData')[role]
-                    ['upgrade_tasks'], role, filepath, step)
+                    ['upgrade_tasks'], filepath, step)
                 self.assertTrue(os.path.isfile(filepath))
                 self.assertEqual(expected_tasks[role][step], playbook_tasks)
 
@@ -875,7 +880,8 @@ class TestConfig(base.TestCase):
         self.config = ooo_config.Config(heat)
         stack = mock.Mock()
         server_roles = dict(Controller='controller')
-        mock_get_network_config_data.return_value = dict(Controller='config')
+        mock_get_network_config_data.return_value = dict(
+            Controller='56f27b7a-7bb8-40bc-bfdb-a46f7f806b88')
         config_dir = '/tmp/tht'
         self.config.render_network_config(stack, config_dir, server_roles)
 
@@ -893,8 +899,9 @@ class TestConfig(base.TestCase):
         self.config = ooo_config.Config(heat)
         stack = mock.Mock()
         server_roles = dict(node1='Controller')
-        mock_get_network_config_data.return_value = dict(node1='config',
-                                                         node2='config')
+        mock_get_network_config_data.return_value = dict(
+            node1='56f27b7a-7bb8-40bc-bfdb-a46f7f806b88',
+            node2='56f27b7a-7bb8-40bc-bfdb-a46f7f806b88')
         config_dir = '/tmp/tht'
         self.config.render_network_config(stack, config_dir, server_roles)
         self.assertEqual(2, mock_open.call_count)
@@ -902,3 +909,107 @@ class TestConfig(base.TestCase):
                          mock_open.call_args_list[0][0][0])
         self.assertEqual('/tmp/tht/Controller/NetworkConfig',
                          mock_open.call_args_list[1][0][0])
+
+    @patch.object(ooo_config.Config, '_open_file')
+    def test_overcloud_config__write_tasks_per_step(self, mock_open_file):
+        heat = mock.MagicMock()
+        self.config = ooo_config.Config(heat)
+
+        # TODO: how can I share this tasks definition between to test
+        # as a fixture So that I do two several test cases instead of
+        # a big one.
+        tasks = [
+            {
+                "when": "step|int == 0",
+                "name": "Simple check"
+            },
+            {
+                "when": "(step|int == 0)",
+                "name": "Check within parenthesis"
+            },
+            {
+                "when": ["step|int == 0", "test1", False],
+                "name": "Check with list with boolean"
+            },
+            {
+                "when": ["test1", False, "step|int == 0"],
+                "name": "Check with list with boolean other order"
+            },
+            {
+                "when": "step|int == 0 or step|int == 3",
+                "name": "Check with boolean expression"
+            },
+            {
+                "when": "(step|int == 0 or step|int == 3) and other_cond",
+                "name": "Complex boolean expression"
+            },
+            {
+                "name": "Task with no conditional"
+            }
+        ]
+
+        # Everything should come back
+        tasks_per_step = self.config._write_tasks_per_step(
+            tasks,
+            'Compute/update_tasks_step0.yaml',
+            0
+        )
+
+        self.assertEqual(tasks, tasks_per_step)
+
+        # Using stict the tasks with no conditional will be dropped
+        tasks_per_step = self.config._write_tasks_per_step(
+            tasks,
+            'Compute/update_tasks_step0.yaml',
+            0,
+            strict=True,
+        )
+
+        expected_tasks = [task for task in tasks
+                          if task != {"name": "Task with no conditional"}]
+        self.assertEqual(expected_tasks,
+                         tasks_per_step)
+
+        # Some tasks will be filtered out for step 3.
+        tasks_per_step = self.config._write_tasks_per_step(
+            tasks,
+            'Compute/update_tasks_step3.yaml',
+            3
+        )
+
+        self.assertEqual(
+            [
+                {
+                    "when": "step|int == 0 or step|int == 3",
+                    "name": "Check with boolean expression"
+                },
+                {
+                    "when": "(step|int == 0 or step|int == 3) and other_cond",
+                    "name": "Complex boolean expression"
+                },
+                {
+                    "name": "Task with no conditional"
+                }
+            ],
+            tasks_per_step)
+
+        # Even more tasks will be filtered out for step 3 with strict.
+        tasks_per_step = self.config._write_tasks_per_step(
+            tasks,
+            'Compute/update_tasks_step3.yaml',
+            3,
+            strict=True,
+        )
+
+        self.assertEqual(
+            [
+                {
+                    "when": "step|int == 0 or step|int == 3",
+                    "name": "Check with boolean expression"
+                },
+                {
+                    "when": "(step|int == 0 or step|int == 3) and other_cond",
+                    "name": "Complex boolean expression"
+                },
+            ],
+            tasks_per_step)
