@@ -19,6 +19,7 @@ import re
 from oslo_utils import netutils
 import six
 
+from ironicclient import exceptions as ironicexceptions
 from oslo_concurrency import processutils
 from tripleo_common import exception
 from tripleo_common.utils import glance
@@ -264,37 +265,6 @@ class iBootDriverInfo(PrefixedDriverInfo):
         return result
 
 
-class UcsDriverInfo(DriverInfo):
-    def __init__(self):
-        mapping = {
-            'pm_addr': 'ucs_address',
-            'pm_user': 'ucs_username',
-            'pm_password': 'ucs_password',
-            'pm_service_profile': 'ucs_service_profile'
-        }
-        mandatory_fields = list(mapping)
-
-        super(UcsDriverInfo, self).__init__(
-            'ucs', mapping,
-            mandatory_fields=mandatory_fields,
-            hardware_type='cisco-ucs-managed',
-        )
-
-    def unique_id_from_fields(self, fields):
-        try:
-            return '%s:%s' % (fields['pm_addr'], fields['pm_service_profile'])
-
-        except KeyError:
-            return
-
-    def unique_id_from_node(self, node):
-        try:
-            return '%s:%s' % (node.driver_info['ucs_address'],
-                              node.driver_info['ucs_service_profile'])
-        except KeyError:
-            return
-
-
 DRIVER_INFO = {
     # production drivers
     '(ipmi|.*_ipmitool)': PrefixedDriverInfo('ipmi', has_port=True,
@@ -306,7 +276,6 @@ DRIVER_INFO = {
                                           hardware_type='idrac'),
     '(ilo|.*_ilo)': PrefixedDriverInfo('ilo', has_port=True,
                                        hardware_type='ilo'),
-    r'(cisco\-ucs\-managed|.*_ucs)': UcsDriverInfo(),
     '(irmc|.*_irmc)': PrefixedDriverInfo('irmc', has_port=True,
                                          hardware_type='irmc'),
     'redfish': RedfishDriverInfo(),
@@ -418,6 +387,9 @@ def register_ironic_node(node, client):
         if field in node:
             create_map.update({field: six.text_type(node[field])})
 
+    conductor_group = node.get("conductor_group")
+    if conductor_group:
+        create_map["conductor_group"] = conductor_group
     node_id = handler.unique_id_from_fields(node)
     LOG.debug('Registering node %s with ironic.', node_id)
     ironic_node = client.node.create(**create_map)
@@ -496,6 +468,7 @@ _NON_DRIVER_FIELDS = {'cpu': '/properties/cpus',
                       'ramdisk_id': ['/driver_info/deploy_ramdisk',
                                      '/driver_info/rescue_ramdisk'],
                       'platform': '/extra/tripleo_platform',
+                      'conductor_group': '/conductor_group',
                       }
 
 _NON_DRIVER_FIELDS.update({field: '/%s' % field
@@ -736,10 +709,16 @@ def generate_hostmap(baremetal_client, compute_client):
     """Create a map between Compute nodes and Baremetal nodes"""
     hostmap = {}
     for node in compute_client.servers.list():
-        bm_node = baremetal_client.node.get_by_instance_uuid(node.id)
-        for port in baremetal_client.port.list(node=bm_node.uuid):
-            hostmap[port.address] = {"compute_name": node.name,
-                                     "baremetal_name": bm_node.name}
+        try:
+            bm_node = baremetal_client.node.get_by_instance_uuid(node.id)
+            for port in baremetal_client.port.list(node=bm_node.uuid):
+                hostmap[port.address] = {"compute_name": node.name,
+                                         "baremetal_name": bm_node.name}
+        except ironicexceptions.NotFound:
+            LOG.warning('Baremetal node for server %s not found - skipping it',
+                        node.id)
+            pass
+
     if hostmap == {}:
         return None
     else:
